summaryrefslogtreecommitdiff
path: root/modules/protocol
diff options
context:
space:
mode:
Diffstat (limited to 'modules/protocol')
-rw-r--r--modules/protocol/bahamut.cpp4
-rw-r--r--modules/protocol/charybdis.cpp4
-rw-r--r--modules/protocol/hybrid.cpp2
-rw-r--r--modules/protocol/inspircd12.cpp6
-rw-r--r--modules/protocol/ngircd.cpp6
-rw-r--r--modules/protocol/ratbox.cpp2
-rw-r--r--modules/protocol/unreal.cpp8
7 files changed, 16 insertions, 16 deletions
diff --git a/modules/protocol/bahamut.cpp b/modules/protocol/bahamut.cpp
index 4e193da01..9fa7e94e9 100644
--- a/modules/protocol/bahamut.cpp
+++ b/modules/protocol/bahamut.cpp
@@ -373,7 +373,7 @@ struct IRCDMessageNick : IRCDMessage
Server *s = Server::Find(params[6]);
if (s == NULL)
{
- Log(LOG_DEBUG) << "User " << params[0] << " introduced from nonexistant server " << params[6] << "?";
+ Log(LOG_DEBUG) << "User " << params[0] << " introduced from non-existent server " << params[6] << "?";
return;
}
@@ -444,7 +444,7 @@ struct IRCDMessageSJoin : IRCDMessage
sju.second = User::Find(buf);
if (!sju.second)
{
- Log(LOG_DEBUG) << "SJOIN for nonexistant user " << buf << " on " << params[1];
+ Log(LOG_DEBUG) << "SJOIN for non-existent user " << buf << " on " << params[1];
continue;
}
diff --git a/modules/protocol/charybdis.cpp b/modules/protocol/charybdis.cpp
index 0801b58f4..9409c320f 100644
--- a/modules/protocol/charybdis.cpp
+++ b/modules/protocol/charybdis.cpp
@@ -229,7 +229,7 @@ struct IRCDMessageEUID : IRCDMessage
}
};
-// we cant use this function from ratbox because we set a local variable here
+// we can't use this function from ratbox because we set a local variable here
struct IRCDMessageServer : IRCDMessage
{
IRCDMessageServer(Module *creator) : IRCDMessage(creator, "SERVER", 3) { SetFlag(IRCDMESSAGE_REQUIRE_SERVER); }
@@ -245,7 +245,7 @@ struct IRCDMessageServer : IRCDMessage
}
};
-// we cant use this function from ratbox because we set a local variable here
+// we can't use this function from ratbox because we set a local variable here
struct IRCDMessagePass : IRCDMessage
{
IRCDMessagePass(Module *creator) : IRCDMessage(creator, "PASS", 4) { SetFlag(IRCDMESSAGE_REQUIRE_SERVER); }
diff --git a/modules/protocol/hybrid.cpp b/modules/protocol/hybrid.cpp
index 150886232..ba46476d9 100644
--- a/modules/protocol/hybrid.cpp
+++ b/modules/protocol/hybrid.cpp
@@ -460,7 +460,7 @@ struct IRCDMessageSJoin : IRCDMessage
sju.second = User::Find(buf);
if (!sju.second)
{
- Log(LOG_DEBUG) << "SJOIN for nonexistant user " << buf << " on " << params[1];
+ Log(LOG_DEBUG) << "SJOIN for non-existent user " << buf << " on " << params[1];
continue;
}
diff --git a/modules/protocol/ngircd.cpp b/modules/protocol/ngircd.cpp
index 28f68007b..4ea9a15ec 100644
--- a/modules/protocol/ngircd.cpp
+++ b/modules/protocol/ngircd.cpp
@@ -451,7 +451,7 @@ struct IRCDMessageNick : IRCDMessage
Server *s = Server::Find(params[4]);
if (s == NULL)
{
- Log(LOG_DEBUG) << "User " << params[0] << " introduced from nonexistant server " << params[4] << "?";
+ Log(LOG_DEBUG) << "User " << params[0] << " introduced from non-existent server " << params[4] << "?";
return;
}
User::OnIntroduce(params[0], params[2], params[3], "", "", s, params[6], Anope::CurTime, params[5], "", NULL);
@@ -500,7 +500,7 @@ struct IRCDMessageNJoin : IRCDMessage
sju.second = User::Find(buf);
if (!sju.second)
{
- Log(LOG_DEBUG) << "NJOIN for nonexistant user " << buf << " on " << params[0];
+ Log(LOG_DEBUG) << "NJOIN for non-existent user " << buf << " on " << params[0];
continue;
}
users.push_back(sju);
@@ -587,7 +587,7 @@ struct IRCDMessageTopic : IRCDMessage
Channel *c = Channel::Find(params[0]);
if (!c)
{
- Log(LOG_DEBUG) << "TOPIC for nonexistant channel " << params[0];
+ Log(LOG_DEBUG) << "TOPIC for non-existent channel " << params[0];
return;
}
c->ChangeTopicInternal(source.GetUser(), source.GetName(), params[1], Anope::CurTime);
diff --git a/modules/protocol/ratbox.cpp b/modules/protocol/ratbox.cpp
index 8ccabd604..da033d3f5 100644
--- a/modules/protocol/ratbox.cpp
+++ b/modules/protocol/ratbox.cpp
@@ -172,7 +172,7 @@ struct IRCDMessageTBurst : IRCDMessage
* params[0] = channel
* params[1] = ts
* params[2] = topic OR who set the topic
- * params[3] = topic if params[2] isnt the topic
+ * params[3] = topic if params[2] isn't the topic
*/
void Run(MessageSource &source, const std::vector<Anope::string> &params) anope_override
{
diff --git a/modules/protocol/unreal.cpp b/modules/protocol/unreal.cpp
index ef8393b74..dccfdc91b 100644
--- a/modules/protocol/unreal.cpp
+++ b/modules/protocol/unreal.cpp
@@ -576,7 +576,7 @@ class ChannelModeFlood : public ChannelModeParam
while (p < arg.length() && isdigit(arg[p]))
++p;
if (p == arg.length() || !(arg[p] == 'c' || arg[p] == 'j' || arg[p] == 'k' || arg[p] == 'm' || arg[p] == 'n' || arg[p] == 't'))
- continue; /* continue instead of break for forward compatability. */
+ continue; /* continue instead of break for forward compatibility. */
try
{
int v = arg.substr(0, p).is_number_only() ? convertTo<int>(arg.substr(0, p)) : 0;
@@ -908,7 +908,7 @@ struct IRCDMessageNick : IRCDMessage
Server *s = Server::Find(params[5]);
if (s == NULL)
{
- Log(LOG_DEBUG) << "User " << params[0] << " introduced from nonexistant server " << params[5] << "?";
+ Log(LOG_DEBUG) << "User " << params[0] << " introduced from non-existent server " << params[5] << "?";
return;
}
@@ -992,7 +992,7 @@ struct IRCDMessageSetHost : IRCDMessage
{
User *u = source.GetUser();
- /* When a user sets +x we recieve the new host and then the mode change */
+ /* When a user sets +x we receive the new host and then the mode change */
if (u->HasMode("CLOAK"))
u->SetDisplayedHost(params[0]);
else
@@ -1096,7 +1096,7 @@ struct IRCDMessageSJoin : IRCDMessage
sju.second = User::Find(buf);
if (!sju.second)
{
- Log(LOG_DEBUG) << "SJOIN for nonexistant user " << buf << " on " << params[1];
+ Log(LOG_DEBUG) << "SJOIN for non-existent user " << buf << " on " << params[1];
continue;
}
diff --git a/modules/protocol/inspircd12.cpp b/modules/protocol/inspircd12.cpp
index 7f080b1d0..e3c61a442 100644
--- a/modules/protocol/inspircd12.cpp
+++ b/modules/protocol/inspircd12.cpp
@@ -949,7 +949,7 @@ struct IRCDMessageFJoin : IRCDMessage
sju.second = User::Find(buf);
if (!sju.second)
{
- Log(LOG_DEBUG) << "FJOIN for nonexistant user " << buf << " on " << params[0];
+ Log(LOG_DEBUG) << "FJOIN for non-existent user " << buf << " on " << params[0];
continue;
}
@@ -1175,7 +1175,7 @@ struct IRCDMessageOperType : IRCDMessage
void Run(MessageSource &source, const std::vector<Anope::string> &params) anope_override
{
/* opertype is equivalent to mode +o because servers
- dont do this directly */
+ don't do this directly */
User *u = source.GetUser();
if (!u->HasMode("OPER"))
u->SetModesInternal(source, "+o");
@@ -1371,7 +1371,7 @@ class ProtoInspIRCd12 : public Module
/* InspIRCd 1.2 doesn't set -r on nick change, remove -r here. Note that if we have to set +r later
* this will cancel out this -r, resulting in no mode changes.
*
* Do not set -r if we dont have a NickServ loaded - DP
*/
BotInfo *NickServ = Config->GetClient("NickServ");
if (NickServ)
@@ -1371,7 +1371,7 @@ class ProtoInspIRCd12 : public Module
* this will cancel out this -r, resulting in no mode changes.
*
- * Do not set -r if we dont have a NickServ loaded - DP
+ * Do not set -r if we don't have a NickServ loaded - DP
*/
BotInfo *NickServ = Config->GetClient("NickServ");